@@ -4,7 +4,9 @@ use strict;
 use warnings;
 use List::MoreUtils qw( any );
 
-our @handlers = qw( changeset wiki report log ticket milestone source attachment);
+our $VERSION = '0.16';
+
+our @handlers = qw( changeset wiki report log ticket milestone source attachment comment );
 
 sub new {
     my $class = shift;
